netapp_ontap.resources.disk API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved …

# Module `netapp_ontap.resources.disk`

Copyright © 2020 NetApp Inc. All rights reserved.

## Retrieving storage disk information

The storage disk GET API retrieves all of the disks in the cluster.

## Examples

### 1) Retrieve a list of disks from the cluster.

#### The following example shows the response with a list of disks in the cluster:

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import Disk

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        print(list(Disk.get_collection()))

Try it out

    [
        Disk({"name": "1.24.4"}),
        Disk({"name": "1.24.3"}),
        Disk({"name": "1.24.5"}),
        Disk({"name": "1.24.0"}),
        Disk({"name": "1.24.2"}),
        Disk({"name": "1.24.1"}),
    ]

### 2) Retrieve a specific disk from the cluster.

#### The following example shows the response of the requested disk. If there is no disk with the requested name, an error is returned:

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import Disk

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = Disk(name="1.24.3")
        resource.get()
        print(resource)

Try it out

    Disk(
        {
            "bay": 3,
            "firmware_version": "NA02",
            "usable_size": 438304768000,
            "class": "performance",
            "uid": "50000394:0808AA88:00000000:00000000:00000000:00000000:00000000:00000000:00000000:00000000",
            "rpm": 10000,
            "name": "1.24.3",
            "home_node": {
                "uuid": "3a89ed49-8c6d-11e8-93bc-00a0985a64b6",
                "name": "node-2",
                "_links": {
                    "self": {
                        "href": "/api/cluster/nodes/3a89ed49-8c6d-11e8-93bc-00a0985a64b6"
                    }
                },
            },
            "serial_number": "EC47PC5021SW",
            "model": "X421_FAL12450A10",
            "type": "sas",
            "aggregates": [
                {
                    "_links": {
                        "self": {
                            "href": "/api/storage/aggregates/3fd9c345-ba91-4949-a7b1-6e2b898d74e3"
                        }
                    },
                    "name": "node_2_SAS_1",
                    "uuid": "3fd9c345-ba91-4949-a7b1-6e2b898d74e3",
                }
            ],
            "container_type": "aggregate",
            "node": {
                "uuid": "3a89ed49-8c6d-11e8-93bc-00a0985a64b6",
                "name": "node-2",
                "_links": {
                    "self": {
                        "href": "/api/cluster/nodes/3a89ed49-8c6d-11e8-93bc-00a0985a64b6"
                    }
                },
            },
            "vendor": "NETAPP",
            "state": "present",
            "pool": "pool0",
            "shelf": {"uid": "10318311901725526608"},
        }
    )

## Modifying storage disk

The storage disk PATCH API modifies disk ownership or encrypting drive authentication keys (AKs) in the cluster.

### Updating the disk ownership for a specified disk

### 1. When the disk is not assigned

When the disk is a spare (or unowned) disk and node name is specified, the PATCH opertaion assigns the disk to the specified node.

### 2. When the disk is already assigned

When the disk is already assigned (aleady has a owner), and a new node is specified, the PATCH operation changes the ownership to the new node.

## Examples

### 1. Update the disk ownership for an unowned disk

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import Disk

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = Disk(name="<disk-name>")
        resource.node.name = "node-name"
        resource.patch()

### 2. Update the disk ownership for an already owned disk.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import Disk

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = Disk(name="<disk-name>")
        resource.node.name = "node-name"
        resource.patch()

### 3. Rekey the data AK of all encrypting drives to an AK selected automatically by the system.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import Disk

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = Disk()
        resource.patch(hydrate=True, name="*", encryption_operation="rekey_data_auto_id")

## Classes

`class Disk (*args, **kwargs)`

  Allows interaction with Disk objects on the host

  Initialize the instance of the resource.

  Any keyword arguments are set on the instance as properties. For example, if the class was named 'MyResource', then this statement would be true:

      MyResource(name='foo').name == 'foo'

  ## Args

  `*args`
    Each positional argument represents a parent key as used in the URL of the object. That is, each value will be used to fill in a segment of the URL which refers to some parent object. The order of these arguments must match the order they are specified in the URL, from left to right.
  `**kwargs`
    each entry will have its key set as an attribute name on the instance and its value will be the value of that attribute.

  ### Ancestors

  - Resource

  ### Static methods

  `def count_collection(*args, connection: HostConnection = None, **kwargs) -> int`

    Retrieves a collection of disks.

    ### Related ONTAP commands

    - `storage disk show`

    ### Learn more

    - `DOC /storage/disks`

    Fetch a count of all objects of this type from the host.

    This calls GET on the object to determine the number of records. It is more efficient than calling get_collection() because it will not construct any objects. Query parameters can be passed in as kwargs to determine a count of objects that match some filtered criteria.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the count of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. These query parameters can affect the count. A return_records query param will be ignored.

    ## Returns

    On success, returns an integer count of the objects of this type. On failure, returns -1.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400, or if there is no connection available to use either passed in or on the library.

  `def find(*args, connection: HostConnection = None, **kwargs) -> Resource`

    Retrieves a collection of disks.

    ### Related ONTAP commands

    - `storage disk show`

    ### Learn more

    - `DOC /storage/disks`

    Find an instance of an object on the host given a query.

    The host will be queried with the provided key/value pairs to find a matching resource. If 0 are found, None will be returned. If more than 1 is found, an error will be raised or returned. If there is exactly 1 matching record, then it will be returned.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to find a bar for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A `Resource` object containing the details of the object or None if no matches were found.

    ## Raises

    `NetAppRestError`: If the API call returned more than 1 matching resource.

  `def get_collection(*args, connection: HostConnection = None, max_records: int = None, **kwargs) -> typing.Iterable`

    Retrieves a collection of disks.

    ### Related ONTAP commands

    - `storage disk show`

    ### Learn more

    - `DOC /storage/disks`

    Fetch a list of all objects of this type from the host.

    This is a lazy fetch, making API calls only as necessary when the result of this call is iterated over. For instance, if max_records is set to 5, then iterating over the collection causes an API call to be sent to the server once for every 5 records. If the client stops iterating before getting to the 6th record, then no additional API calls are made.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the collection of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `max_records`
      The maximum number of records to return per call
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A list of `Resource` objects

    ## Raises

    `NetAppRestError`: If there is no connection available to use either passed in or on the library. This would be not be raised when get_collection() is called, but rather when the result is iterated.

  `def patch_collection(body: dict, *args, connection: HostConnection = None, **kwargs) -> NetAppResponse`

    Updates disk ownership or authentication keys.

    ### Related ONTAP commands

    - `storage disk assign`
    - `storage encryption disk modify -data-key-id`
    - `security key-manager key query -key-type NSE-AK`

    ### Learn more

    - `DOC /storage/disks`

    Patch all objects in a collection which match the given query.

    All records on the host which match the query will be patched with the provided body.

    ## Args

    `body`
      A dictionary of name/value pairs to set on all matching members of the collection.
    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to patch the collection of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. Only resources matching this query will be patched.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  ### Methods

  `def get(self, **kwargs) -> NetAppResponse`

    Retrieves a specific disk.

    ### Related ONTAP commands

    - `storage disk show`

    ### Learn more

    - `DOC /storage/disks`

    Fetch the details of the object from the host.

    Requires the keys to be set (if any). After returning, new or changed properties from the host will be set on the instance.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  ### Inherited members

  - `Resource`:
    - `from_dict`
    - `get_collection_url`
    - `get_connection`
    - `instance_location`
    - `path_keys`
    - `poll`
    - `set_connection`
    - `to_dict`
`class DiskSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the Disk object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `aggregates GET`

    List of aggregates sharing this disk

  `bay GET`

    Disk shelf bay

    Example: 1

  `class_ GET`

    Disk class

    Valid choices:

    - unknown
    - capacity
    - performance
    - archive
    - solid_state
    - array
    - virtual
  `container_type GET`

    Type of overlying disk container

    Valid choices:

    - aggregate
    - broken
    - foreign
    - labelmaint
    - maintenance
    - shared
    - spare
    - unassigned
    - unknown
    - unsupported
    - remote
    - mediator
  `dr_node GET`

    The dr_node field of the disk.

  `drawer GET POST PATCH`

    The drawer field of the disk.

  `encryption_operation PATCH`

    Encryption operation to apply to the drives. Possible values are: - rekey_data_default - rekey_data_auto_id

  `fips_certified GET`

    The fips_certified field of the disk.

  `firmware_version GET`

    The firmware_version field of the disk.

    Example: NA51

  `home_node GET`

    The home_node field of the disk.

  `key_id GET POST PATCH`

    The key_id field of the disk.

  `model GET`

    The model field of the disk.

    Example: X421_HCOBE450A10

  `name GET`

    Cluster-wide disk name

    Example: 1.0.1

  `node GET PATCH`

    The node field of the disk.

  `pool GET`

    Pool to which disk is assigned

    Valid choices:

    - pool0
    - pool1
    - failed
    - none
  `protection_mode GET`

    Mode of drive data protection and FIPS compliance. Possible values are: - open - Disk is unprotected - data - Data protection only without FIPS compliance - part - Partial protection with FIPS compliance only - full - Full data and FIPS compliance protection

    Valid choices:

    - open
    - data
    - part
    - full
  `rated_life_used_percent GET`

    Percentage of rated life used

    Example: 10

  `rpm GET`

    Revolutions per minute

    Example: 15000

  `self_encrypting GET`

    The self_encrypting field of the disk.

  `serial_number GET`

    The serial_number field of the disk.

    Example: KHG2VX8R

  `shelf GET`

    The shelf field of the disk.

  `state GET`

    State

    Valid choices:

    - broken
    - copy
    - maintenance
    - partner
    - pending
    - present
    - reconstructing
    - removed
    - spare
    - unfail
    - zeroing
  `type GET`

    Disk interface type

    Valid choices:

    - ata
    - bsas
    - fcal
    - fsas
    - lun
    - sas
    - msata
    - ssd
    - vmdisk
    - unknown
    - ssd_cap
    - ssd_nvm
  `uid GET`

    The unique identifier for a disk

    Example: 002538E5:71B00B2F:00000000:00000000:00000000:00000000:00000000:00000000:00000000:00000000

  `usable_size GET`

    The usable_size field of the disk.

    Example: 959934889984

  `vendor GET`

    The vendor field of the disk.

    Example: NETAPP